Module cache

Module cache 

Cache layer for liquid cache.

Re-exports

pub use policies::AlwaysHydrate;
pub use policies::CachePolicy;
pub use policies::HydrationPolicy;
pub use policies::HydrationRequest;
pub use policies::LiquidPolicy;
pub use policies::MaterializedEntry;
pub use policies::NoHydration;
pub use policies::SqueezePolicy;
pub use policies::TranscodeSqueezeEvict;

Modules

cache_policies
Legacy path: re-export cache policy types under cache::cache_policies.
hydration_policies
Legacy path: re-export hydration policy types under cache::hydration_policies.
policies
Policy modules for cache eviction, hydration, and squeezing.
squeeze_policies
Legacy path: re-export squeeze policy types under cache::squeeze_policies.

Structs

CacheFull
The cache could not reserve enough disk budget for a write.
CacheStats
Snapshot of cache statistics.
DefaultCacheMetadata
A default implementation of EntryMetadata.
DefaultSqueezeIo
A default implementation of SqueezeIoHandler backed by a t4::Store.
EntryID
EntryID is a unique identifier for a batch of rows, i.e., the cache key.
EvaluatePredicate
Builder for predicate evaluation on cached data.
EventTrace
A trace of events that occurred in the cache. This is used for testing only.
Get
Builder returned by LiquidCache::get for configuring cache reads.
Insert
Builder returned by LiquidCache::insert for configuring cache writes.
LiquidCache
Cache storage for liquid cache.
LiquidCacheBuilder
Builder for LiquidCache.
LiquidCompressorStates
States for liquid compressor.
LiquidExpr
A predicate expression validated for LiquidCache predicate evaluation.
Observer
Cache-side observer for runtime stats, debug traces, and optional cache tracing.
RuntimeStats
Atomic runtime counters for cache API calls.
RuntimeStatsSnapshot
Immutable snapshot of RuntimeStats.
VariantRequest
A typed variant path requested by a query.

Enums

CacheEntry
A cached entry storing data in various formats.
CacheExpression
Experimental expression descriptor for cache lookups.
CachedBatchType
The type of the cached batch.

Traits

EntryMetadata
Per-entry metadata used by the cache.

Functions

transcode_liquid_inner
This method is used to transcode an arrow array into a liquid array.
transcode_liquid_inner_with_hint
Transcode with an optional hint to precompute metadata (e.g., substring fingerprints).