pub enum CacheEntry {
MemoryArrow(ArrayRef),
MemoryLiquid(LiquidArrayRef),
MemorySqueezedLiquid(LiquidSqueezedArrayRef),
DiskLiquid(DataType),
DiskArrow(DataType),
}Expand description
A cached entry storing data in various formats.
Variants
MemoryArrow(ArrayRef)
Cached batch in memory as Arrow array.
MemoryLiquid(LiquidArrayRef)
Cached batch in memory as liquid array.
MemorySqueezedLiquid(LiquidSqueezedArrayRef)
Cached batch in memory as squeezed liquid array.
DiskLiquid(DataType)
Cached batch on disk as liquid array.
DiskArrow(DataType)
Cached batch on disk as Arrow array.
Implementations
Sourceimpl CacheEntry
impl CacheEntry
Sourcepub fn memory_arrow(array: ArrayRef) -> Self
pub fn memory_arrow(array: ArrayRef) -> Self
Construct a cached batch stored as an in-memory Arrow array.
Sourcepub fn memory_liquid(array: LiquidArrayRef) -> Self
pub fn memory_liquid(array: LiquidArrayRef) -> Self
Construct a cached batch stored as an in-memory Liquid array.
Sourcepub fn memory_squeezed_liquid(array: LiquidSqueezedArrayRef) -> Self
pub fn memory_squeezed_liquid(array: LiquidSqueezedArrayRef) -> Self
Construct a cached batch stored as an in-memory squeezed Liquid array.
Sourcepub fn disk_liquid(data_type: DataType) -> Self
pub fn disk_liquid(data_type: DataType) -> Self
Construct a cached batch stored on disk as Liquid bytes.
Sourcepub fn disk_arrow(data_type: DataType) -> Self
pub fn disk_arrow(data_type: DataType) -> Self
Construct a cached batch stored on disk as Arrow bytes.
Sourcepub fn memory_usage_bytes(&self) -> usize
pub fn memory_usage_bytes(&self) -> usize
Memory usage reported by the underlying representation.
Sourcepub fn reference_count(&self) -> usize
pub fn reference_count(&self) -> usize
Reference count (if any) of the backing storage.