transcode_liquid_inner

Function transcode_liquid_inner 

pub fn transcode_liquid_inner<'a>(
    array: &'a ArrayRef,
    state: &LiquidCompressorStates,
) -> Result<LiquidArrayRef, &'a ArrayRef>
This method is used to transcode an arrow array into a liquid array.

Returns the transcoded liquid array if successful, otherwise returns the original arrow array.