Module hydration

Module hydration 

Hydration policies decide whether and how to promote squeezed/on-disk entries back into memory.

Structs

AlwaysHydrate
Default hydration policy: always keep a materialized cache miss in memory by promoting along the path: disk -> squeezed -> liquid -> arrow.
HydrationRequest
Request context provided to a HydrationPolicy.
NoHydration
No hydration policy: never promote a materialized entry back into memory.

Enums

MaterializedEntry
The materialized representation produced by a cache read.

Traits

HydrationPolicy
Decide if a materialized entry should be promoted back into memory.