Module squeeze

Module squeeze 

Squeeze policies for liquid cache.

Structs

Evict
Squeeze the entry to disk.
TranscodeEvict
Squeeze the entry to liquid memory, but don’t convert to squeezed.
TranscodeSqueezeEvict
Squeeze the entry to liquid memory.

Enums

SqueezeOutcome
What to do when we need to squeeze an entry?

Traits

SqueezePolicy
Policy that chooses the next representation for an entry under memory pressure.