pub enum SqueezeOutcome {
Replace {
entry: CacheEntry,
bytes_to_write: Option<Bytes>,
},
Remove,
}Expand description
What to do when we need to squeeze an entry?
Variants
Replace
Replace the cache entry, optionally writing bytes to disk first.
Fields

entry: CacheEntryReplacement cache entry.
Remove
Remove the entry entirely.