pub struct Observer { /* private fields */ }Expand description
Cache-side observer for runtime stats, debug traces, and optional cache tracing.
Implementations
Sourceimpl Observer
impl Observer
Sourcepub fn runtime_snapshot(&self) -> RuntimeStatsSnapshotInner
pub fn runtime_snapshot(&self) -> RuntimeStatsSnapshotInner
Snapshot runtime counters and reset them to zero.
Sourcepub fn consume_event_trace(&self) -> EventTrace
pub fn consume_event_trace(&self) -> EventTrace
Consume and clear the in-memory debug event trace.
Sourcepub fn enable_cache_trace(&self)
pub fn enable_cache_trace(&self)
Enable recording cache trace events (for offline analysis).
Sourcepub fn disable_cache_trace(&self)
pub fn disable_cache_trace(&self)
Disable recording cache trace events.
Sourcepub fn flush_cache_trace(&self, to_file: impl AsRef<Path>)
pub fn flush_cache_trace(&self, to_file: impl AsRef<Path>)
Flush recorded cache trace events to a Parquet file.
Sourcepub fn cache_tracer(&self) -> &CacheTracer
pub fn cache_tracer(&self) -> &CacheTracer
Access the underlying cache tracer.