Module liquid_array

Module liquid_array 

LiquidArray is the core data structure of LiquidCache. You should not use this module directly. Instead, use liquid_cache_datafusion_server or liquid_cache_datafusion_client to interact with LiquidCache.

Re-exports

pub use byte_view_array::LiquidByteViewArray;

Modules

byte_view_array
LiquidByteViewArray
ipc
IPC for liquid array.
raw
Low level array primitives. You should not use this module directly. Instead, use liquid_cache_datafusion_server or liquid_cache_datafusion_client to interact with LiquidCache.

Structs

LiquidByteArray
An array that stores strings in a dictionary format, with a bit-packed array for the keys and a FSST array for the values.
LiquidDecimalArray
Liquid decimal array stored as a compressed u64 primitive.
LiquidFixedLenByteArray
A fixed length byte array.
LiquidFloatArray
An array that stores floats in ALP
LiquidLinearArray
A linear-model based integer array, only use it when you know the array is monotonic and you don’t care about encoding speed!.
LiquidPrimitiveArray
Liquid’s primitive array
LiquidPrimitiveDeltaArray
Liquid’s primitive array which uses delta encoding for compression
NeedsBacking
Signals that the squeezed representation needs to be hydrated from disk.
SqueezedDate32Array
A bit-packed array that stores a single extracted component (YEAR/MONTH/DAY/DOW) from a Date32/Timestamp array.
VariantStructSqueezedArray
Squeezed representation for variant arrays that contain multiple typed fields.

Enums

Date32Field
Which component to extract from a Date32/Timestamp (days since UNIX epoch).
IntegerSqueezePolicy
Squeeze policy for primitive integer arrays. Users can choose whether to clamp or quantize when squeezing.
LiquidDataType
Liquid data type is only logical type
SqueezedBacking
On-disk backing type for a hybrid array.

Traits

AsLiquidArray
A trait to access the underlying Liquid array.
LiquidArray
A Liquid array.
LiquidPrimitiveType
LiquidPrimitiveType is a sealed trait that represents the primitive types supported by Liquid. Implemented for all supported integer, date, and timestamp Arrow primitive types.
LiquidSqueezedArray
A Liquid squeezed array is a Liquid array that part of its data is stored on disk. LiquidSqueezedArray is more complex than in-memory LiquidArray because it needs to handle IO.
PrimitiveKind
Compile-time info about primitive kind (signed vs unsigned) and bounds. Implemented for all Liquid-supported primitive integer and date types.
SqueezeIoHandler
A trait to read the backing bytes of a squeezed array from disk.

Functions

get_bytes_needle
Extract a byte needle from a scalar value for string comparison operations.
get_string_needle
Extract a string needle from a scalar value for string comparison operations.

Type Aliases

LiquidArrayRef
A reference to a Liquid array.
LiquidDate32Array
Liquid’s 32-bit date array.
LiquidDate64Array
Liquid’s 64-bit date array.
LiquidFloat32Array
Liquid’s single-precision floating point array
LiquidFloat64Array
Liquid’s double precision floating point array
LiquidI8Array
Liquid’s signed 8-bit integer array.
LiquidI16Array
Liquid’s signed 16-bit integer array.
LiquidI32Array
Liquid’s signed 32-bit integer array.
LiquidI64Array
Liquid’s signed 64-bit integer array.
LiquidLinearDate32Array
Linear-model array for Date32 (days since epoch).
LiquidLinearDate64Array
Linear-model array for Date64 (ms since epoch).
LiquidLinearI8Array
Linear-model array for i8.
LiquidLinearI16Array
Linear-model array for i16.
LiquidLinearI32Array
Backward-compatible alias for i32.
LiquidLinearI64Array
Linear-model array for i64.
LiquidLinearU8Array
Linear-model array for u8.
LiquidLinearU16Array
Linear-model array for u16.
LiquidLinearU32Array
Linear-model array for u32.
LiquidLinearU64Array
Linear-model array for u64.
LiquidSqueezedArrayRef
A reference to a Liquid squeezed array.
LiquidU8Array
Liquid’s unsigned 8-bit integer array.
LiquidU16Array
Liquid’s unsigned 16-bit integer array.
LiquidU32Array
Liquid’s unsigned 32-bit integer array.
LiquidU64Array
Liquid’s unsigned 64-bit integer array.
SqueezeResult
Result type for squeezed operations that may require disk hydration.