LiquidByteViewArray

Struct LiquidByteViewArray 

pub struct LiquidByteViewArray<B: FsstBacking> { /* private fields */ }
An array that stores strings using the FSST format with compact offsets:

  • Dictionary keys with 2-byte keys stored in memory
  • Compact offsets with variable-size residuals (1, 2, or 4 bytes) stored in memory
  • Per-value prefix keys (7-byte prefix + len) stored in memory
  • FSST buffer can be stored in memory or on disk

Initialization

The recommended way to create a LiquidByteViewArray is using the from_*_array constructors which build a compact (offset + prefix key) representation directly from Arrow inputs.

let liquid_array = LiquidByteViewArray::from_string_array(&input, compressor);

Data access flow:

  1. Use dictionary key to index into compact offsets buffer
  2. Reconstruct actual offset from linear regression (predicted + residual)
  3. Use prefix keys for quick comparisons to avoid decompression when possible
  4. Decompress bytes from FSST buffer to get the full value when needed

Implementations

Source

impl LiquidByteViewArray<FsstArray>

pub fn compare_with(&self, needle: &[u8], op: &ByteViewOperator) -> BooleanArray

Compare with prefix optimization and fallback to Arrow operations

Source

impl<B: FsstBacking> LiquidByteViewArray<B>

pub fn prefix_compare_counts( &self, needle: &[u8], op: &Comparison, ) -> (usize, usize, usize)

Return (selected_rows, ambiguous_rows, unique_rows) based on prefix-only comparison.

Source

impl<B: FsstBacking> LiquidByteViewArray<B>

pub fn from_string_view_array( array: &StringViewArray, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Create a LiquidByteViewArray from an Arrow StringViewArray

pub fn from_binary_view_array( array: &BinaryViewArray, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Create a LiquidByteViewArray from an Arrow BinaryViewArray

pub fn from_string_array( array: &StringArray, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Create a LiquidByteViewArray from an Arrow StringArray

pub fn from_binary_array( array: &BinaryArray, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Create a LiquidByteViewArray from an Arrow BinaryArray

pub fn train_from_string_view( array: &StringViewArray, ) -> (Arc<Compressor>, LiquidByteViewArray<FsstArray>)

Train a compressor from an Arrow StringViewArray

pub fn train_from_binary_view( array: &BinaryViewArray, ) -> (Arc<Compressor>, LiquidByteViewArray<FsstArray>)

Train a compressor from an Arrow BinaryViewArray

pub fn train_from_arrow<T: ByteArrayType>( array: &GenericByteArray<T>, ) -> (Arc<Compressor>, LiquidByteViewArray<FsstArray>)

Train a compressor from an Arrow ByteArray.

pub unsafe fn from_unique_dict_array( array: &DictionaryArray<UInt16Type>, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Only used when the dictionary is read from a trusted parquet reader, which reads a trusted parquet file, written by a trusted writer.

Safety

The caller must ensure that the values in the dictionary are unique.

pub fn train_from_arrow_dict( array: &DictionaryArray<UInt16Type>, ) -> (Arc<Compressor>, LiquidByteViewArray<FsstArray>)

Train a compressor from an Arrow DictionaryArray.

pub fn train_compressor<'a, T: ArrayAccessor<Item = &'a str>>( array: ArrayIter<T>, ) -> Arc<Compressor>

Train a compressor from an iterator of strings

pub fn train_compressor_bytes<'a, T: ArrayAccessor<Item = &'a [u8]>>( array: ArrayIter<T>, ) -> Arc<Compressor>

Train a compressor from an iterator of byte arrays

Source

impl LiquidByteViewArray<FsstArray>

pub fn from_bytes( bytes: Bytes, compressor: Arc<Compressor>, ) -> LiquidByteViewArray<FsstArray>

Deserialize a LiquidByteViewArray from bytes.

Source

impl<B: FsstBacking> LiquidByteViewArray<B>

pub fn nulls(&self) -> Option<&NullBuffer>

Get the nulls buffer

pub fn get_detailed_memory_usage(&self) -> ByteViewArrayMemoryUsage

Get detailed memory usage of the byte view array

pub fn len(&self) -> usize

Get the length of the array

pub fn is_empty(&self) -> bool

Is the array empty?

Source

impl LiquidByteViewArray<FsstArray>

pub fn to_dict_arrow(&self) -> DictionaryArray<UInt16Type>

Convert to Arrow DictionaryArray

pub fn to_arrow_array(&self) -> ArrayRef

Convert to Arrow array with original type

pub fn is_fsst_buffer_on_disk(&self) -> bool

Check if the FSST buffer is currently stored on disk

Source

impl LiquidByteViewArray<DiskBuffer>

pub fn is_fsst_buffer_on_disk(&self) -> bool

Check if the FSST buffer is currently stored on disk

pub async fn to_dict_arrow(&self) -> DictionaryArray<UInt16Type>

Convert to Arrow DictionaryArray

pub async fn to_arrow_array(&self) -> ArrayRef

Convert to Arrow array with original type