pub fn get_bytes_needle(value: &ScalarValue) -> Option<Vec<u8>>Expand description
Extract a byte needle from a scalar value for string comparison operations.
pub fn get_bytes_needle(value: &ScalarValue) -> Option<Vec<u8>>Extract a byte needle from a scalar value for string comparison operations.