Module fsst_buffer

Module fsst_buffer 

FSST dictionary backing used by byte-view arrays.

Structs

DiskBuffer
Disk buffer for FSST buffer.
FsstArray
In-memory FSST dictionary buffer that bundles compressed bytes, compact offsets, and the compressor needed to (de)compress values.

Traits

FsstBacking
FSST backing store for LiquidByteViewArray (in-memory or disk-only handle).

Functions

load_symbol_table
Loads symbol table from a buffer saved by save_symbol_table.
save_symbol_table
Saves symbol table from the compressor to a buffer.