save_symbol_table

Function save_symbol_table 

pub fn save_symbol_table(
    compressor: Arc<Compressor>,
    buffer: &mut Vec<u8>,
) -> Result<()>
Saves symbol table from the compressor to a buffer.

Format:

  1. The first byte is the length of the symbol table as a u8.
  2. The next bytes are the lengths of each symbol as u8.
  3. The next bytes are the symbols as u64.