pub struct BitPackedArray<T: ArrowPrimitiveType>where
T::Native: BitPacking,{ /* private fields */ }Expand description
A bit-packed array.
Implementations
Sourceimpl<T: ArrowPrimitiveType> BitPackedArray<T>where
T::Native: BitPacking,
impl<T: ArrowPrimitiveType> BitPackedArray<T>where
T::Native: BitPacking,
Sourcepub fn new_null_array(len: usize) -> Self
pub fn new_null_array(len: usize) -> Self
Creates a new null array with the given length.
Sourcepub fn from_primitive(array: PrimitiveArray<T>, bit_width: NonZero<u8>) -> Self
pub fn from_primitive(array: PrimitiveArray<T>, bit_width: NonZero<u8>) -> Self
Creates a new bit-packed array from a primitive array and a bit width.
Sourcepub fn to_primitive(&self) -> PrimitiveArray<T>
pub fn to_primitive(&self) -> PrimitiveArray<T>
Converts the bit-packed array to a primitive array.
Sourcepub fn get_array_memory_size(&self) -> usize
pub fn get_array_memory_size(&self) -> usize
Returns the memory size of the bit-packed array.
Sourcepub fn from_bytes(bytes: Bytes) -> Selfwhere
T::Native: BitPacking,
pub fn from_bytes(bytes: Bytes) -> Selfwhere
T::Native: BitPacking,
Deserializes a bit-packed array from a byte buffer.