pub struct LiquidByteArray { /* private fields */ }Expand description
An array that stores strings in a dictionary format, with a bit-packed array for the keys and a FSST array for the values.
Implementations
Sourceimpl LiquidByteArray
impl LiquidByteArray
Sourcepub fn from_bytes(bytes: Bytes, compressor: Arc<Compressor>) -> Self
pub fn from_bytes(bytes: Bytes, compressor: Arc<Compressor>) -> Self
Deserialize a LiquidByteArray from bytes, using zero-copy where possible.
Sourceimpl LiquidByteArray
impl LiquidByteArray
Sourcepub fn from_string_view_array(
array: &StringViewArray,
compressor: Arc<Compressor>,
) -> Self
pub fn from_string_view_array( array: &StringViewArray, compressor: Arc<Compressor>, ) -> Self
Create a LiquidByteArray from an Arrow StringViewArray.
Sourcepub fn from_binary_view_array(
array: &BinaryViewArray,
compressor: Arc<Compressor>,
) -> Self
pub fn from_binary_view_array( array: &BinaryViewArray, compressor: Arc<Compressor>, ) -> Self
Create a LiquidByteArray from an Arrow BinaryViewArray.
Sourcepub fn train_compressor_bytes<'a, T: ArrayAccessor<Item = &'a [u8]>>(
array: ArrayIter<T>,
) -> Arc<Compressor>
pub fn train_compressor_bytes<'a, T: ArrayAccessor<Item = &'a [u8]>>( array: ArrayIter<T>, ) -> Arc<Compressor>
Train a compressor from an iterator of byte arrays.
Sourcepub fn train_compressor<'a, T: ArrayAccessor<Item = &'a str>>(
array: ArrayIter<T>,
) -> Arc<Compressor>
pub fn train_compressor<'a, T: ArrayAccessor<Item = &'a str>>( array: ArrayIter<T>, ) -> Arc<Compressor>
Train a compressor from an iterator of strings.
Sourcepub fn from_string_array(
array: &StringArray,
compressor: Arc<Compressor>,
) -> Self
pub fn from_string_array( array: &StringArray, compressor: Arc<Compressor>, ) -> Self
Create a LiquidByteArray from an Arrow StringArray.
Sourcepub fn from_byte_array<T: ByteArrayType>(
array: &GenericByteArray<T>,
compressor: Arc<Compressor>,
) -> Self
pub fn from_byte_array<T: ByteArrayType>( array: &GenericByteArray<T>, compressor: Arc<Compressor>, ) -> Self
Create a LiquidByteArray from an Arrow ByteArray.
Sourcepub fn train_from_string_view(
array: &StringViewArray,
) -> (Arc<Compressor>, Self)
pub fn train_from_string_view( array: &StringViewArray, ) -> (Arc<Compressor>, Self)
Train a compressor from an Arrow StringViewArray.
Sourcepub fn train_from_binary_view(
array: &BinaryViewArray,
) -> (Arc<Compressor>, Self)
pub fn train_from_binary_view( array: &BinaryViewArray, ) -> (Arc<Compressor>, Self)
Train a compressor from an Arrow BinaryViewArray.
Sourcepub fn train_from_arrow<T: ByteArrayType>(
array: &GenericByteArray<T>,
) -> (Arc<Compressor>, Self)
pub fn train_from_arrow<T: ByteArrayType>( array: &GenericByteArray<T>, ) -> (Arc<Compressor>, Self)
Train a compressor from an Arrow ByteArray.
Sourcepub fn train_from_arrow_dict(
array: &DictionaryArray<UInt16Type>,
) -> (Arc<Compressor>, Self)
pub fn train_from_arrow_dict( array: &DictionaryArray<UInt16Type>, ) -> (Arc<Compressor>, Self)
Train a compressor from an Arrow DictionaryArray.
Sourcepub unsafe fn from_unique_dict_array(
array: &DictionaryArray<UInt16Type>,
compressor: Arc<Compressor>,
) -> Self
pub unsafe fn from_unique_dict_array( array: &DictionaryArray<UInt16Type>, compressor: Arc<Compressor>, ) -> Self
Only used when the dictionary is read from a trusted parquet reader, which reads a trusted parquet file, written by a trusted writer.
Safety
The caller must ensure that the values in the dictionary are unique.
Sourcepub fn from_dict_array(
array: &DictionaryArray<UInt16Type>,
compressor: Arc<Compressor>,
) -> Self
pub fn from_dict_array( array: &DictionaryArray<UInt16Type>, compressor: Arc<Compressor>, ) -> Self
Create a LiquidByteArray from an Arrow DictionaryArray.
Sourcepub fn decompressor(&self) -> Decompressor<'_>
pub fn decompressor(&self) -> Decompressor<'_>
Get the decompressor of the LiquidStringArray.
Sourcepub fn to_dict_arrow(&self) -> DictionaryArray<UInt16Type>
pub fn to_dict_arrow(&self) -> DictionaryArray<UInt16Type>
Convert the LiquidStringArray to arrow’s DictionaryArray.
Sourcepub fn to_dict_arrow_with_selection(
&self,
selection: &BooleanArray,
) -> DictionaryArray<UInt16Type>
pub fn to_dict_arrow_with_selection( &self, selection: &BooleanArray, ) -> DictionaryArray<UInt16Type>
Convert the LiquidStringArray to a DictionaryArray with a selection.
Sourcepub fn to_arrow_array(&self) -> ArrayRef
pub fn to_arrow_array(&self) -> ArrayRef
Convert the LiquidStringArray to a StringArray.
Sourcepub fn compare_not_equals(&self, needle: &str) -> BooleanArray
pub fn compare_not_equals(&self, needle: &str) -> BooleanArray
Compare the values of the LiquidStringArray with a given string and return a BooleanArray of the result.
Sourcepub fn nulls(&self) -> Option<&NullBuffer>
pub fn nulls(&self) -> Option<&NullBuffer>
Get the nulls of the LiquidStringArray.
Sourcepub fn compare_equals(&self, needle: &str) -> BooleanArray
pub fn compare_equals(&self, needle: &str) -> BooleanArray
Compare the values of the LiquidStringArray with a given string. Leverage the distinct values to speed up the comparison. TODO: We can further optimize this by vectorizing the comparison.