pub struct LiquidFixedLenByteArray { /* private fields */ }Expand description
A fixed length byte array.
Implementations
Sourceimpl LiquidFixedLenByteArray
impl LiquidFixedLenByteArray
Sourcepub fn from_bytes(bytes: Bytes, compressor: Arc<Compressor>) -> Self
pub fn from_bytes(bytes: Bytes, compressor: Arc<Compressor>) -> Self
Deserialize a LiquidFixedLenByteArray from bytes, using zero-copy where possible.
Sourceimpl LiquidFixedLenByteArray
impl LiquidFixedLenByteArray
Sourcepub fn from_decimal_array<T: DecimalType>(
array: &PrimitiveArray<T>,
compressor: Arc<Compressor>,
) -> Self
pub fn from_decimal_array<T: DecimalType>( array: &PrimitiveArray<T>, compressor: Arc<Compressor>, ) -> Self
Create a new fixed length byte array from a decimal array.
Sourcepub fn train_from_decimal_array<T: DecimalType>(
array: &PrimitiveArray<T>,
) -> (Arc<Compressor>, Self)
pub fn train_from_decimal_array<T: DecimalType>( array: &PrimitiveArray<T>, ) -> (Arc<Compressor>, Self)
Train a new fixed length byte array from a decimal array.