LiquidFloatArray

Struct LiquidFloatArray 

pub struct LiquidFloatArray<T: LiquidFloatType> { /* private fields */ }
An array that stores floats in ALP

Implementations

Source

impl<T> LiquidFloatArray<T>
where T: LiquidFloatType,

pub fn is_empty(&self) -> bool

Check if the Liquid float array is empty.

pub fn len(&self) -> usize

Get the length of the Liquid float array.

pub fn get_array_memory_size(&self) -> usize

Get the memory size of the Liquid primitive array.

pub fn from_arrow_array(arrow_array: PrimitiveArray<T>) -> LiquidFloatArray<T>

Create a Liquid primitive array from an Arrow float array.

pub fn squeeze_policy(&self) -> FloatSqueezePolicy

Get current squeeze policy for this array

Source

impl<T> LiquidFloatArray<T>
where T: LiquidFloatType,

pub fn from_bytes(bytes: Bytes) -> Self

Deserialize a LiquidFloatArray from bytes, using zero-copy where possible.