pub struct LiquidLinearArray<T: LiquidPrimitiveType>{ /* private fields */ }Expand description
A linear-model based integer array, only use it when you know the array is monotonic and you don’t care about encoding speed!.
Under the hood, it uses a linear model to predict the values and store the residuals: value[i] = intercept + round(slope * i) + residual[i]
Where intercept and slope are computed using a L-infinity linear fit, this is time-consuming!.
This array is only recommended if you know the array follows a linear model, e.g., kinetic values, offsets, etc.
Examples of not recommended use cases: random values like ids, categorical values, etc.
Implementations
Sourceimpl<T> LiquidLinearArray<T>
impl<T> LiquidLinearArray<T>
Sourcepub fn from_arrow_array(arrow_array: PrimitiveArray<T>) -> Self
pub fn from_arrow_array(arrow_array: PrimitiveArray<T>) -> Self
Build from an Arrow PrimitiveArray<T> by training a linear model
using a fast L-infinity fit (Option 3) and storing residuals.
Sourcepub fn from_bytes(bytes: Bytes) -> Self
pub fn from_bytes(bytes: Bytes) -> Self
Decode a LiquidLinearArray<T> from bytes.