pub struct LiquidPrimitiveArray<T: LiquidPrimitiveType> { /* private fields */ }Expand description
Liquid’s primitive array
Implementations
Sourceimpl<T> LiquidPrimitiveArray<T>where
T: LiquidPrimitiveType,
impl<T> LiquidPrimitiveArray<T>where
T: LiquidPrimitiveType,
Sourcepub fn get_array_memory_size(&self) -> usize
pub fn get_array_memory_size(&self) -> usize
Get the memory size of the Liquid primitive array.
Sourcepub fn from_arrow_array(
arrow_array: PrimitiveArray<T>,
) -> LiquidPrimitiveArray<T>
pub fn from_arrow_array( arrow_array: PrimitiveArray<T>, ) -> LiquidPrimitiveArray<T>
Create a Liquid primitive array from an Arrow primitive array.
Sourcepub fn squeeze_policy(&self) -> IntegerSqueezePolicy
pub fn squeeze_policy(&self) -> IntegerSqueezePolicy
Get the current squeeze policy for this array.
Sourcepub fn set_squeeze_policy(&mut self, policy: IntegerSqueezePolicy)
pub fn set_squeeze_policy(&mut self, policy: IntegerSqueezePolicy)
Set the squeeze policy for this array.
Sourcepub fn with_squeeze_policy(self, policy: IntegerSqueezePolicy) -> Self
pub fn with_squeeze_policy(self, policy: IntegerSqueezePolicy) -> Self
Set the squeeze policy, returning self for chaining.
Sourceimpl<T> LiquidPrimitiveArray<T>where
T: LiquidPrimitiveType,
impl<T> LiquidPrimitiveArray<T>where
T: LiquidPrimitiveType,
Sourcepub fn from_bytes(bytes: Bytes) -> Self
pub fn from_bytes(bytes: Bytes) -> Self
Deserialize a LiquidPrimitiveArray from bytes