pub struct LiquidPrimitiveDeltaArray<T: LiquidPrimitiveType> { /* private fields */ }Expand description
Liquid’s primitive array which uses delta encoding for compression
Implementations
Sourceimpl<T> LiquidPrimitiveDeltaArray<T>where
T: LiquidPrimitiveType,
impl<T> LiquidPrimitiveDeltaArray<T>where
T: LiquidPrimitiveType,
Sourcepub fn get_array_memory_size(&self) -> usize
pub fn get_array_memory_size(&self) -> usize
Get the memory size of the Liquid primitive delta array.
Sourcepub fn from_arrow_array(
arrow_array: PrimitiveArray<T>,
) -> LiquidPrimitiveDeltaArray<T>
pub fn from_arrow_array( arrow_array: PrimitiveArray<T>, ) -> LiquidPrimitiveDeltaArray<T>
Create a Liquid primitive delta array from an Arrow primitive array.
Sourceimpl<T> LiquidPrimitiveDeltaArray<T>where
T: LiquidPrimitiveType,
impl<T> LiquidPrimitiveDeltaArray<T>where
T: LiquidPrimitiveType,
Sourcepub fn from_bytes(bytes: Bytes) -> Self
pub fn from_bytes(bytes: Bytes) -> Self
Deserialize a LiquidPrimitiveDeltaArray from bytes