SqueezeIoHandler

Trait SqueezeIoHandler 

pub trait SqueezeIoHandler:
    Debug
    + Send
    + Sync {
    // Required method
    fn read<'life0, 'async_trait>(
        &'life0 self,
        range: Option<Range<u64>>,
    ) -> Pin<Box<dyn Future<Output = Result<Bytes>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided methods
    fn tracing_decompress_count(
        &self,
        _decompress_cnt: usize,
        _total_cnt: usize,
    ) { ... }
    fn trace_io_saved(&self) { ... }
}
A trait to read the backing bytes of a squeezed array from disk.

Required Methods

fn read<'life0, 'async_trait>( &'life0 self, range: Option<Range<u64>>, ) -> Pin<Box<dyn Future<Output = Result<Bytes>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Read the backing bytes of a squeezed array from disk.

Provided Methods

fn tracing_decompress_count(&self, _decompress_cnt: usize, _total_cnt: usize)

Trace the number of decompressions performed.

fn trace_io_saved(&self)

Trace the number of IO saved by squeezing.

Implementors