Cache layer for liquid cache.
Re-exports
pub use policies::AlwaysHydrate;pub use policies::CachePolicy;pub use policies::HydrationPolicy;pub use policies::HydrationRequest;pub use policies::LiquidPolicy;pub use policies::MaterializedEntry;pub use policies::NoHydration;pub use policies::SqueezePolicy;pub use policies::TranscodeSqueezeEvict;
Modules
- cache_
policies - Legacy path: re-export cache policy types under
cache::cache_policies. - hydration_
policies - Legacy path: re-export hydration policy types under
cache::hydration_policies. - policies
- Policy modules for cache eviction, hydration, and squeezing.
- squeeze_
policies - Legacy path: re-export squeeze policy types under
cache::squeeze_policies.
Structs
- Cache
Stats - Snapshot of cache statistics.
- Default
IoContext - A default implementation of IoContext that uses the default compressor. It uses tokio’s async IO by default.
- Default
Squeeze Io - A default implementation of SqueezeIoHandler that uses the default IoContext.
- EntryID
- EntryID is a unique identifier for a batch of rows, i.e., the cache key.
- Evaluate
Predicate - Builder for predicate evaluation on cached data.
- Event
Trace - A trace of events that occurred in the cache. This is used for testing only.
- Get
- Builder returned by
LiquidCache::getfor configuring cache reads. - Insert
- Builder returned by
LiquidCache::insertfor configuring cache writes. - Liquid
Cache - Cache storage for liquid cache.
- Liquid
Cache Builder - Builder for LiquidCache.
- Liquid
Compressor States - States for liquid compressor.
- Observer
- Cache-side observer for runtime stats, debug traces, and optional cache tracing.
- Runtime
Stats - Atomic runtime counters for cache API calls.
- Runtime
Stats Snapshot - Immutable snapshot of
RuntimeStats. - Variant
Request - A typed variant path requested by a query.
Enums
- Cache
Entry - A cached entry storing data in various formats.
- Cache
Expression - Experimental expression descriptor for cache lookups.
- Cached
Batch Type - The type of the cached batch.
Traits
- IoContext
- A trait for objects that can handle IO operations for the cache.
Functions
- transcode_
liquid_ inner - This method is used to transcode an arrow array into a liquid array.
- transcode_
liquid_ inner_ with_ hint - Transcode with an optional hint to precompute metadata (e.g., substring fingerprints).