Hydration policies decide whether and how to promote squeezed/on-disk entries back into memory.
Structs
- Always
Hydrate - Default hydration policy: always keep a materialized cache miss in memory by promoting along the path: disk -> squeezed -> liquid -> arrow.
- Hydration
Request - Request context provided to a
HydrationPolicy. - NoHydration
- No hydration policy: never promote a materialized entry back into memory.
Enums
- Materialized
Entry - The materialized representation produced by a cache read.
Traits
- Hydration
Policy - Decide if a materialized entry should be promoted back into memory.