LiquidArray is the core data structure of LiquidCache.
You should not use this module directly.
Instead, use liquid_cache_datafusion_server or liquid_cache_datafusion_client to interact with LiquidCache.
Re-exports
pub use byte_view_array::LiquidByteViewArray;
Modules
- byte_
view_ array - LiquidByteViewArray
- ipc
- IPC for liquid array.
- raw
- Low level array primitives.
You should not use this module directly.
Instead, use
liquid_cache_datafusion_serverorliquid_cache_datafusion_clientto interact with LiquidCache.
Structs
- Liquid
Byte Array - An array that stores strings in a dictionary format, with a bit-packed array for the keys and a FSST array for the values.
- Liquid
Decimal Array - Liquid decimal array stored as a compressed u64 primitive.
- Liquid
Fixed LenByte Array - A fixed length byte array.
- Liquid
Float Array - An array that stores floats in ALP
- Liquid
Linear Array - A linear-model based integer array, only use it when you know the array is monotonic and you don’t care about encoding speed!.
- Liquid
Primitive Array - Liquid’s primitive array
- Liquid
Primitive Delta Array - Liquid’s primitive array which uses delta encoding for compression
- Needs
Backing - Signals that the squeezed representation needs to be hydrated from disk.
- Squeezed
Date32 Array - A bit-packed array that stores a single extracted component (YEAR/MONTH/DAY/DOW)
from a
Date32/Timestamp array. - Variant
Struct Squeezed Array - Squeezed representation for variant arrays that contain multiple typed fields.
Enums
- Date32
Field - Which component to extract from a
Date32/Timestamp (days since UNIX epoch). - Integer
Squeeze Policy - Squeeze policy for primitive integer arrays. Users can choose whether to clamp or quantize when squeezing.
- Liquid
Data Type - Liquid data type is only logical type
- Squeezed
Backing - On-disk backing type for a hybrid array.
Traits
- AsLiquid
Array - A trait to access the underlying Liquid array.
- Liquid
Array - A Liquid array.
- Liquid
Primitive Type - LiquidPrimitiveType is a sealed trait that represents the primitive types supported by Liquid. Implemented for all supported integer, date, and timestamp Arrow primitive types.
- Liquid
Squeezed Array - A Liquid squeezed array is a Liquid array that part of its data is stored on disk.
LiquidSqueezedArrayis more complex than in-memoryLiquidArraybecause it needs to handle IO. - Primitive
Kind - Compile-time info about primitive kind (signed vs unsigned) and bounds. Implemented for all Liquid-supported primitive integer and date types.
- Squeeze
IoHandler - A trait to read the backing bytes of a squeezed array from disk.
Functions
- get_
bytes_ needle - Extract a byte needle from a scalar value for string comparison operations.
- get_
string_ needle - Extract a string needle from a scalar value for string comparison operations.
Type Aliases
- Liquid
Array Ref - A reference to a Liquid array.
- Liquid
Date32 Array - Liquid’s 32-bit date array.
- Liquid
Date64 Array - Liquid’s 64-bit date array.
- Liquid
Float32 Array - Liquid’s single-precision floating point array
- Liquid
Float64 Array - Liquid’s double precision floating point array
- Liquid
I8Array - Liquid’s signed 8-bit integer array.
- Liquid
I16Array - Liquid’s signed 16-bit integer array.
- Liquid
I32Array - Liquid’s signed 32-bit integer array.
- Liquid
I64Array - Liquid’s signed 64-bit integer array.
- Liquid
Linear Date32 Array - Linear-model array for
Date32(days since epoch). - Liquid
Linear Date64 Array - Linear-model array for
Date64(ms since epoch). - Liquid
Linear I8Array - Linear-model array for
i8. - Liquid
Linear I16Array - Linear-model array for
i16. - Liquid
Linear I32Array - Backward-compatible alias for i32.
- Liquid
Linear I64Array - Linear-model array for
i64. - Liquid
Linear U8Array - Linear-model array for
u8. - Liquid
Linear U16Array - Linear-model array for
u16. - Liquid
Linear U32Array - Linear-model array for
u32. - Liquid
Linear U64Array - Linear-model array for
u64. - Liquid
Squeezed Array Ref - A reference to a Liquid squeezed array.
- Liquid
U8Array - Liquid’s unsigned 8-bit integer array.
- Liquid
U16Array - Liquid’s unsigned 16-bit integer array.
- Liquid
U32Array - Liquid’s unsigned 32-bit integer array.
- Liquid
U64Array - Liquid’s unsigned 64-bit integer array.
- Squeeze
Result - Result type for squeezed operations that may require disk hydration.