FSST dictionary backing used by byte-view arrays.
Structs
- Disk
Buffer - Disk buffer for FSST buffer.
- Fsst
Array - In-memory FSST dictionary buffer that bundles compressed bytes, compact offsets, and the compressor needed to (de)compress values.
Traits
- Fsst
Backing - FSST backing store for
LiquidByteViewArray(in-memory or disk-only handle).
Functions
- load_
symbol_ table - Loads symbol table from a buffer saved by
save_symbol_table. - save_
symbol_ table - Saves symbol table from the compressor to a buffer.