LiquidFixedLenByteArray

Struct LiquidFixedLenByteArray 

pub struct LiquidFixedLenByteArray { /* private fields */ }
A fixed length byte array.

Implementations

Source

impl LiquidFixedLenByteArray

pub fn from_bytes(bytes: Bytes, compressor: Arc<Compressor>) -> Self

Deserialize a LiquidFixedLenByteArray from bytes, using zero-copy where possible.

Source

impl LiquidFixedLenByteArray

pub fn from_decimal_array<T: DecimalType>( array: &PrimitiveArray<T>, compressor: Arc<Compressor>, ) -> Self

Create a new fixed length byte array from a decimal array.

pub fn train_from_decimal_array<T: DecimalType>( array: &PrimitiveArray<T>, ) -> (Arc<Compressor>, Self)

Train a new fixed length byte array from a decimal array.