pub struct LiquidFloatArray<T: LiquidFloatType> { /* private fields */ }Expand description
An array that stores floats in ALP
Implementations
Sourceimpl<T> LiquidFloatArray<T>where
T: LiquidFloatType,
impl<T> LiquidFloatArray<T>where
T: LiquidFloatType,
Sourcepub fn get_array_memory_size(&self) -> usize
pub fn get_array_memory_size(&self) -> usize
Get the memory size of the Liquid primitive array.
Sourcepub fn from_arrow_array(arrow_array: PrimitiveArray<T>) -> LiquidFloatArray<T>
pub fn from_arrow_array(arrow_array: PrimitiveArray<T>) -> LiquidFloatArray<T>
Create a Liquid primitive array from an Arrow float array.
Sourcepub fn squeeze_policy(&self) -> FloatSqueezePolicy
pub fn squeeze_policy(&self) -> FloatSqueezePolicy
Get current squeeze policy for this array
Sourceimpl<T> LiquidFloatArray<T>where
T: LiquidFloatType,
impl<T> LiquidFloatArray<T>where
T: LiquidFloatType,
Sourcepub fn from_bytes(bytes: Bytes) -> Self
pub fn from_bytes(bytes: Bytes) -> Self
Deserialize a LiquidFloatArray from bytes, using zero-copy where possible.